@@ -1,8 +1,9 @@
 pub mod balanced_tree;
 pub mod bit;
-pub mod disjoint_set;
 pub mod heaparray;
 pub mod priority_queue;
 pub mod queue;
+pub mod sparse_table;
+pub mod union_find;
 pub mod vector;
 pub mod vector_int;
